@@ -266,7 +266,7 @@ static void _notify_timeout_destroy(NotifyTimeout* nt)
 
 static gboolean do_exit(gpointer user_data)
 {
-	exit(0);
+	gtk_main_quit();
 	return FALSE;
 }
 
@@ -687,6 +687,13 @@ typedef struct {
 	gint id;
 } IdleRepositionData;
 
+static void idle_reposition_data_destroy(gpointer user_data)
+{
+	IdleRepositionData* data = (IdleRepositionData*) user_data;
+	g_object_unref(data->daemon);
+	g_free(data);
+}
+
 static gboolean idle_reposition_notification(IdleRepositionData* data)
 {
 	NotifyDaemon* daemon;
@@ -705,8 +712,6 @@ static gboolean idle_reposition_notification(IdleRepositionData* data)
 	}
 
 	g_hash_table_remove(daemon->idle_reposition_notify_ids, GINT_TO_POINTER(notify_id));
-	g_object_unref(daemon);
-	g_free(data);
 
 	return FALSE;
 }
@@ -729,7 +734,7 @@ static void _queue_idle_reposition_notification(NotifyDaemon* daemon, gint notif
 	data->id = notify_id;
 
 	/* We do this as a short timeout to avoid repositioning spam */
-	idle_id = g_timeout_add_full(G_PRIORITY_LOW, 50, (GSourceFunc) idle_reposition_notification, data, NULL);
+	idle_id = g_timeout_add_full(G_PRIORITY_LOW, 50, (GSourceFunc) idle_reposition_notification, data, idle_reposition_data_destroy);
 	g_hash_table_insert(daemon->idle_reposition_notify_ids, GINT_TO_POINTER(notify_id), GUINT_TO_POINTER(idle_id));
 }
 
@@ -1183,22 +1188,29 @@ static gboolean screensaver_active(GtkWidget* nw)
 #ifdef HAVE_X11
 static gboolean fullscreen_window_exists(GtkWidget* nw)
 {
+	WnckHandle* wnck_handle;
 	WnckScreen* wnck_screen;
 	WnckWorkspace* wnck_workspace;
 	GList* l;
+	gboolean retval = FALSE;
 
 	g_return_val_if_fail (GDK_IS_X11_DISPLAY (gdk_display_get_default ()), FALSE);
 
-	wnck_screen = wnck_screen_get (GDK_SCREEN_XNUMBER (gdk_window_get_screen (gtk_widget_get_window (nw))));
+	wnck_handle = wnck_handle_new (WNCK_CLIENT_TYPE_APPLICATION);
+
+	g_return_val_if_fail (WNCK_IS_HANDLE (wnck_handle), FALSE);
+
+	wnck_screen = wnck_handle_get_screen (wnck_handle, GDK_SCREEN_XNUMBER (gdk_window_get_screen (gtk_widget_get_window (nw))));
+
+	if (!wnck_screen)
+		goto cleanup;
 
 	wnck_screen_force_update (wnck_screen);
 
 	wnck_workspace = wnck_screen_get_active_workspace (wnck_screen);
 
 	if (!wnck_workspace)
-	{
-		return FALSE;
-	}
+		goto cleanup;
 
 	for (l = wnck_screen_get_windows_stacked (wnck_screen); l != NULL; l = l->next)
 	{
@@ -1219,12 +1231,15 @@ static gboolean fullscreen_window_exists(GtkWidget* nw)
 
 			if (sw == w && sh == h)
 			{
-				return TRUE;
+				retval = TRUE;
+				goto cleanup;
 			}
 		}
 	}
 
-	return FALSE;
+cleanup:
+	g_clear_object (&wnck_handle);
+	return retval;
 }
 
 static Window get_window_parent(GdkDisplay* display, Window window, Window* root)
@@ -1371,7 +1386,7 @@ static gboolean notify_daemon_notify_handler(NotifyDaemonNotifications *object,
 	if (g_hash_table_size (daemon->notification_hash) > MAX_NOTIFICATIONS)
 	{
 		g_dbus_method_invocation_return_error (invocation, notify_daemon_error_quark(), 1, _("Exceeded maximum number of notifications"));
-		return FALSE;
+		return TRUE;
 	}
 
 	/* Grab the settings */
@@ -1592,14 +1607,24 @@ static gboolean notify_daemon_notify_handler(NotifyDaemonNotifications *object,
 							      g_settings_get_int(daemon->gsettings, GSETTINGS_KEY_MONITOR_NUMBER));
 		}
 
-		if (_gtk_get_monitor_num (monitor_id) >= daemon->screen->n_stacks)
+		/* If the monitor was disconnected or invalid, fall back to the last available monitor */
+		if (monitor_id == NULL && daemon->screen->n_stacks > 0)
+		{
+			monitor_id = gdk_display_get_monitor (gdk_display_get_default(), (int) daemon->screen->n_stacks - 1);
+		}
+
+		if (monitor_id != NULL && _gtk_get_monitor_num (monitor_id) >= daemon->screen->n_stacks)
 		{
 			/* screw it - dump it on the last one we'll get
 			 a monitors-changed signal soon enough*/
 			monitor_id = gdk_display_get_monitor (gdk_display_get_default(), (int) daemon->screen->n_stacks - 1);
 		}
 
-		notify_stack_add_window (daemon->screen->stacks[_gtk_get_monitor_num (monitor_id)], nw, new_notification);
+		/* If we still don't have a valid monitor, something is seriously wrong */
+		if (monitor_id != NULL && daemon->screen->n_stacks > 0)
+		{
+			notify_stack_add_window (daemon->screen->stacks[_gtk_get_monitor_num (monitor_id)], nw, new_notification);
+		}
 	}
 
 	if (id == 0)
@@ -1676,7 +1701,7 @@ static gboolean notify_daemon_close_notification_handler(NotifyDaemonNotificatio
 	if (id == 0)
 	{
 		g_dbus_method_invocation_return_error (invocation, notify_daemon_error_quark(), 100,  _("%u is not a valid notification ID"), id);
-		return FALSE;
+		return TRUE;
 	}
 	else
 	{
