@@ -50,6 +50,11 @@ GList* notify_stack_get_windows(NotifyStack *stack)
 	return stack->windows;
 }
 
+GdkMonitor* notify_stack_get_monitor(NotifyStack *stack)
+{
+	return stack->monitor;
+}
+
 #ifdef HAVE_X11
 static gboolean
 get_work_area (NotifyStack  *stack,
@@ -69,7 +74,6 @@ get_work_area (NotifyStack  *stack,
 
 	workarea = XInternAtom(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "_NET_WORKAREA", True);
 
-
         disp_screen = GDK_SCREEN_XNUMBER (stack->screen);
 
         /* Defaults in case of error */
@@ -81,7 +85,6 @@ get_work_area (NotifyStack  *stack,
         if (workarea == None)
                 return FALSE;
 
-
 	win = XRootWindow(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), disp_screen);
 
 	result = XGetWindowProperty(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()),
@@ -97,7 +100,6 @@ get_work_area (NotifyStack  *stack,
 		&leftovers,
 		&ret_workarea);
 
-
         if (result != Success
             || type == None
             || format == 0
