@@ -28,6 +28,8 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <libxml/xpath.h>
 
 /* Define basic coco types */
@@ -66,7 +68,6 @@ typedef struct
 	GtkTextDirection rtl;
 } WindowData;
 
-
 enum
 {
 	URGENCY_LOW,
@@ -344,8 +345,6 @@ action_clicked_cb(GtkWidget *w, GdkEventButton *event,
 	action_cb(nw, key);
 }
 
-
-
 /* Required functions */
 
 /* Checking if we support this notification daemon version */
@@ -452,7 +451,6 @@ create_notification(UrlClickedCb url_clicked)
 	gtk_widget_show (vbox);
 	gtk_box_pack_start (GTK_BOX (windata->main_hbox), vbox, TRUE, TRUE, 0);
 
-
 	windata->summary_label = gtk_label_new(NULL);
 	gtk_widget_show(windata->summary_label);
 	gtk_box_pack_start(GTK_BOX(vbox), windata->summary_label, FALSE, FALSE, 0);
@@ -546,7 +544,7 @@ set_notification_text(GtkWindow *nw, const char *summary, const char *body)
 		if ((body_label_text == NULL) || (strlen (body_label_text) == 0)) {
 			goto render_fail;
 		}
-		goto renrer_ok;
+		goto render_ok;
 	}
 
 render_fail:
@@ -557,7 +555,7 @@ render_fail:
 	g_free (quoted);
 	g_free (str);
 
-renrer_ok:
+render_ok:
 	xmlCleanupParser ();
 
 	if (body == NULL || *body == '\0')
@@ -708,7 +706,6 @@ move_notification(GtkWidget *nw, int x, int y)
     gtk_window_move(GTK_WINDOW(nw), x, y);
 }
 
-
 /* Optional Functions */
 
 /* Destroy notification */
